# TODO

A list of outstanding tasks, features, or technical debt to be addressed in this project.

## Features

- [ ] Workspace restore

## Refactoring / Debt

- [ ] Integrate with GoodDataApiClient
- [ ] Consider replacing the SdkMethods wrapper with direct calls to the SDK methods
- [ ] Cleanup custom exceptions
- [ ] Improve test coverage. Write missing unit tests for legacy code (e.g., user data filters)

## Documentation

- [ ] Improve package README
- [ ] User data filter provisioning
